==> pandoc-crossref-0.2.6.0-19-i686.pkg.tar.xz: usr/share/haskell/register/pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-crossref
version: 0.2.6.0
id: pandoc-crossref-0.2.6.0-Ch9SvsY4mKZ8r0abKhP09r
key: pandoc-crossref-0.2.6.0-Ch9SvsY4mKZ8r0abKhP09r
license: GPL-2
maintainer: root@livid.pp.ru
synopsis: Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.
category: Text
author: Nikolay Yakimov
exposed: True
indefinite: False
exposed-modules:
    Text.Pandoc.CrossRef
hidden-modules: Text.Pandoc.CrossRef.References
                Text.Pandoc.CrossRef.References.Blocks
                Text.Pandoc.CrossRef.References.List
                Text.Pandoc.CrossRef.References.Refs
                Text.Pandoc.CrossRef.References.Types
                Text.Pandoc.CrossRef.Util.Settings Text.Pandoc.CrossRef.Util.Meta
                Text.Pandoc.CrossRef.Util.Options
                Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util
                Text.Pandoc.CrossRef.Util.CustomLabels
                Text.Pandoc.CrossRef.Util.CodeBlockCaptions
                Text.Pandoc.CrossRef.Util.ModifyMeta
                Text.Pandoc.CrossRef.Util.Settings.Gen
                Text.Pandoc.CrossRef.Util.Settings.Template
                Text.Pandoc.CrossRef.Util.Gap
                Text.Pandoc.CrossRef.Util.PandocOrphans
abi: 90ca2003518b373436827c147a95b2ae
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/pandoc-crossref-0.2.6.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/pandoc-crossref-0.2.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/pandoc-crossref
hs-libraries: HSpandoc-crossref-0.2.6.0-Ch9SvsY4mKZ8r0abKhP09r
depends:
    base-4.10.0.0 pandoc-1.19.2.1-5c3XIfQW0IdI85TPAAmyLk
    pandoc-types-1.17.2-Fl8qYoEQbpODaVFN2ZWOXB
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3 containers-0.5.10.2
    data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J
    data-accessor-0.2.2.7-5Cbm9y1KpXt9rK4kBtrZpd
    data-accessor-template-0.2.1.14-6Go7K9P9umBBZ39WK0SSpO
    data-accessor-transformers-0.2.1.7-4EAwGiE1PUmD13VxzjMHw3
    template-haskell-2.12.0.0
    roman-numerals-0.5.1.5-DfQbuaqOgHFHOvEGKNSjfB
    syb-0.7-2rRPTNxBP6YFePrCXw4i2o
    utility-ht-0.0.14-4br28cWzxu32AcVJ156WVj directory-1.3.0.2
    filepath-1.4.1.2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             pandoc-1.19.2.1-5c3XIfQW0IdI85TPAAmyLk=15812ee9de6001d8940e9a903632f0f3
             pandoc-types-1.17.2-Fl8qYoEQbpODaVFN2ZWOXB=671e07ddd80a4e21a2a78e76900b479f
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J=066f8e1a5e7dca2a5fd62aefb939793f
             data-accessor-0.2.2.7-5Cbm9y1KpXt9rK4kBtrZpd=7027d747b3708b7adef6a76b51091034
             data-accessor-template-0.2.1.14-6Go7K9P9umBBZ39WK0SSpO=3cdefa8a9dd75e112c98094a40bf9c6f
             data-accessor-transformers-0.2.1.7-4EAwGiE1PUmD13VxzjMHw3=f3a6c6a41166a4bfc25503b3ed67c03b
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
             roman-numerals-0.5.1.5-DfQbuaqOgHFHOvEGKNSjfB=ddea3db37d792be6d6814afbdd98a942
             syb-0.7-2rRPTNxBP6YFePrCXw4i2o=db83b83263dcafbe734df45ece7027fc
             utility-ht-0.0.14-4br28cWzxu32AcVJ156WVj=1a1809eb8ba2e75eb9ba0f6b65f67465
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
haddock-interfaces: /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html: /usr/share/doc/pandoc-crossref/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> pandoc-crossref-0.2.6.0-20-i686.pkg.tar.xz: usr/share/haskell/register/pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-crossref
version: 0.2.6.0
id: pandoc-crossref-0.2.6.0-1xqwoutASHGC2KyOEsGQUz
key: pandoc-crossref-0.2.6.0-1xqwoutASHGC2KyOEsGQUz
license: GPL-2
maintainer: root@livid.pp.ru
synopsis: Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.
category: Text
author: Nikolay Yakimov
exposed: True
indefinite: False
exposed-modules:
    Text.Pandoc.CrossRef
hidden-modules: Text.Pandoc.CrossRef.References
                Text.Pandoc.CrossRef.References.Blocks
                Text.Pandoc.CrossRef.References.List
                Text.Pandoc.CrossRef.References.Refs
                Text.Pandoc.CrossRef.References.Types
                Text.Pandoc.CrossRef.Util.Settings Text.Pandoc.CrossRef.Util.Meta
                Text.Pandoc.CrossRef.Util.Options
                Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util
                Text.Pandoc.CrossRef.Util.CustomLabels
                Text.Pandoc.CrossRef.Util.CodeBlockCaptions
                Text.Pandoc.CrossRef.Util.ModifyMeta
                Text.Pandoc.CrossRef.Util.Settings.Gen
                Text.Pandoc.CrossRef.Util.Settings.Template
                Text.Pandoc.CrossRef.Util.Gap
                Text.Pandoc.CrossRef.Util.PandocOrphans
abi: bc704c53dd5947441bb3b1467eb5f280
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/pandoc-crossref-0.2.6.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/pandoc-crossref-0.2.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/pandoc-crossref
hs-libraries: HSpandoc-crossref-0.2.6.0-1xqwoutASHGC2KyOEsGQUz
depends:
    base-4.10.0.0 pandoc-1.19.2.1-6LS3gm1xTuF2jxYP0d5ZMM
    pandoc-types-1.17.2-Fl8qYoEQbpODaVFN2ZWOXB
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3 containers-0.5.10.2
    data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J
    data-accessor-0.2.2.7-5Cbm9y1KpXt9rK4kBtrZpd
    data-accessor-template-0.2.1.14-6Go7K9P9umBBZ39WK0SSpO
    data-accessor-transformers-0.2.1.7-4EAwGiE1PUmD13VxzjMHw3
    template-haskell-2.12.0.0
    roman-numerals-0.5.1.5-DfQbuaqOgHFHOvEGKNSjfB
    syb-0.7-2rRPTNxBP6YFePrCXw4i2o
    utility-ht-0.0.14-4br28cWzxu32AcVJ156WVj directory-1.3.0.2
    filepath-1.4.1.2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             pandoc-1.19.2.1-6LS3gm1xTuF2jxYP0d5ZMM=ce6d7820dff3844a49d63f4cf00807c0
             pandoc-types-1.17.2-Fl8qYoEQbpODaVFN2ZWOXB=671e07ddd80a4e21a2a78e76900b479f
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J=066f8e1a5e7dca2a5fd62aefb939793f
             data-accessor-0.2.2.7-5Cbm9y1KpXt9rK4kBtrZpd=7027d747b3708b7adef6a76b51091034
             data-accessor-template-0.2.1.14-6Go7K9P9umBBZ39WK0SSpO=3cdefa8a9dd75e112c98094a40bf9c6f
             data-accessor-transformers-0.2.1.7-4EAwGiE1PUmD13VxzjMHw3=f3a6c6a41166a4bfc25503b3ed67c03b
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
             roman-numerals-0.5.1.5-DfQbuaqOgHFHOvEGKNSjfB=ddea3db37d792be6d6814afbdd98a942
             syb-0.7-2rRPTNxBP6YFePrCXw4i2o=db83b83263dcafbe734df45ece7027fc
             utility-ht-0.0.14-4br28cWzxu32AcVJ156WVj=1a1809eb8ba2e75eb9ba0f6b65f67465
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
haddock-interfaces: /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html: /usr/share/doc/pandoc-crossref/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
